@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2013 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package accounts
 
@@ -214,9 +199,15 @@ func NewUdcpUser(usrId uint32, service *dbusutil.Service, groups []string) (*Use
 		PasswordLastChange: 18737,
 	}
 
-	u.AccountType = users.UserTypeUdcp
 	u.Groups = groups
 
+	// 解析对应域管用户是否有添加到sudo组里面，有为管理员用户，否则为标准用户
+	if strv.Strv(groups).Contains("sudo") {
+		u.AccountType = users.UserTypeAdmin
+	} else {
+		u.AccountType = users.UserTypeStandard
+	}
+
 	loadUserConfigInfo(u)
 	return u, err
 }
