@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2014 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package audio
 
@@ -178,6 +163,8 @@ type Audio struct {
 	// 自动端口切换
 	enableAutoSwitchPort bool
 	systemSigLoop        *dbusutil.SignalLoop
+	// 用来进一步断是否需要暂停播放的信息
+	misc uint32
 
 	// nolint
 	signals *struct {
@@ -366,6 +353,8 @@ func (a *Audio) refreshSources() {
 			delete(a.sources, key)
 		}
 	}
+
+	a.updatePropSources()
 }
 
 func (a *Audio) refershSinkInputs() {
@@ -448,9 +437,17 @@ func (a *Audio) autoPause() {
 		port, err = card.Ports.Get(a.defaultSink.ActivePort.Name, pulse.DirectionSink)
 	}
 
-	if err != nil || port.Available == pulse.AvailableTypeNo || card.ActiveProfile.Name == "off" {
+	if err != nil {
 		logger.Warning(err)
 		pauseAllPlayers()
+	} else if card.ActiveProfile.Name == "off" {
+		pauseAllPlayers()
+	} else if port.Available == pulse.AvailableTypeNo {
+		// 使用优先级并且未开启自动切换时，先不暂停，后面根据sink信息判断是否需要暂停
+		a.misc = port.Priority
+		if a.misc == 0 || a.canAutoSwitchPort() {
+			pauseAllPlayers()
+		}
 	}
 }
 
@@ -460,9 +457,33 @@ func (a *Audio) refreshDefaultSinkSource() {
 
 	if a.defaultSink != nil && a.defaultSink.Name != defaultSink {
 		logger.Debugf("update default sink to %s", defaultSink)
+		if a.misc != 0 {
+			a.misc = 0
+			go pauseAllPlayers()
+		}
 		a.updateDefaultSink(defaultSink)
 	} else {
 		logger.Debugf("keep default as %s", defaultSink)
+		if a.misc != 0 {
+			if card, err := a.ctx.GetCard(a.defaultSink.Card); err == nil {
+				port, err := card.Ports.Get(a.defaultSink.ActivePort.Name, pulse.DirectionSink)
+				if err != nil {
+					logger.Warning(err)
+					go pauseAllPlayers()
+				} else {
+					switch DetectPortType(card, &port) {
+					case PortTypeBluetooth, PortTypeHeadset, PortTypeLineIO, PortTypeUsb:
+						// 优先级变低了才暂停播放
+						if port.Priority < a.misc {
+							go pauseAllPlayers()
+						}
+					default:
+						go pauseAllPlayers()
+					}
+				}
+			}
+			a.misc = 0
+		}
 	}
 
 	if a.defaultSource != nil && a.defaultSource.Name != defaultSource {
