@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2014 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package bluetooth
 
@@ -102,7 +87,7 @@ func notify(icon, summary, body string) {
 
 // notify pc initiative connect to device
 // so do not need to show notification window
-func notifyInitiativeConnect(dev *DeviceInfo, pinCode string) error {
+func notifyInitiativeConnect(dev *DeviceInfo, pinCode string, needCancel string) error {
 	if checkProcessExists(bluetoothDialog) {
 		logger.Info("initiative already exist")
 		return nil
@@ -111,7 +96,7 @@ func notifyInitiativeConnect(dev *DeviceInfo, pinCode string) error {
 	timestamp := strconv.FormatInt(time.Now().UnixNano(), 10)
 	//use command to open osd window to show pin code
 	// #nosec G204
-	cmd := exec.Command(notifyDdeDialogPath, pinCode, string(dev.Path), timestamp)
+	cmd := exec.Command(notifyDdeDialogPath, pinCode, string(dev.Path), timestamp, needCancel)
 	err := cmd.Start()
 	if err != nil {
 		logger.Infof("execute cmd command failed,err:%v", err)
