@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2014 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package dock
 
@@ -151,20 +136,13 @@ func (m *Manager) currentWM() string {
 	return wmName
 }
 
-func (m *Manager) is3DWM() (ret bool) {
+func (m *Manager) is3DWM() bool {
 	m.PropsMu.Lock()
 	defer m.PropsMu.Unlock()
 	if m.wmName == "" {
-		var err error
 		m.wmName = m.currentWM()
-		if err != nil {
-			logger.Warning("failed to get wmSwitcher.CurrentWM:", err)
-		}
 	}
-	if m.wmName == wmName3D {
-		ret = true
-	}
-	return
+	return m.wmName == wmName3D
 }
 
 func (m *Manager) handleLauncherItemDeleted(itemInfo launcher.ItemInfo) {
