@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package keybinding
 
@@ -750,6 +735,18 @@ func (m *Manager) handleKeyEventByWayland(changKey string) {
 		}
 
 	} else if action.Type == shortcuts.ActionTypeToggleWireless {
+		// 如果已经开启了飞行模式，则不能通过快捷键去控制wifi的使能
+		enabled, err := m.airplane.Enabled().Get(0)
+		if err != nil {
+			logger.Warningf("get airplane enabled failed, err: %v", err)
+			return
+		}
+
+		if enabled {
+			logger.Debugf("airplane mode enabled, can not enable wireless by key")
+			return
+		}
+
 		// check if allow set wireless
 		// and check if Wifi shortcut effected by DDE software
 		if m.gsMediaKey.GetBoolean(gsKeyUpperLayerWLAN) && m.wifiControlEnable {
