@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package shortcuts
 
@@ -36,6 +21,7 @@ import (
 	"github.com/linuxdeepin/go-lib/keyfile"
 	"github.com/linuxdeepin/go-lib/log"
 	"github.com/linuxdeepin/go-lib/pinyin_search"
+	"github.com/linuxdeepin/go-lib/strv"
 	dutils "github.com/linuxdeepin/go-lib/utils"
 	x "github.com/linuxdeepin/go-x11-client"
 	"github.com/linuxdeepin/go-x11-client/ext/record"
@@ -163,14 +149,14 @@ type KeyEvent struct {
 func NewShortcutManager(conn *x.Conn, keySymbols *keysyms.KeySymbols, eventCb KeyEventFunc) *ShortcutManager {
 	setUseWayland(strings.Contains(os.Getenv("XDG_SESSION_TYPE"), "wayland"))
 	ss := &ShortcutManager{
-		idShortcutMap:         make(map[string]Shortcut),
-		eventCb:               eventCb,
-		conn:                  conn,
-		keySymbols:            keySymbols,
-		recordEnable:          true,
-		keyKeystrokeMap:       make(map[Key]*Keystroke),
-		layoutChanged:         make(chan struct{}),
-		pinyinEnabled:         isZH(),
+		idShortcutMap:            make(map[string]Shortcut),
+		eventCb:                  eventCb,
+		conn:                     conn,
+		keySymbols:               keySymbols,
+		recordEnable:             true,
+		keyKeystrokeMap:          make(map[Key]*Keystroke),
+		layoutChanged:            make(chan struct{}),
+		pinyinEnabled:            isZH(),
 		WaylandCustomShortCutMap: make(map[string]string),
 	}
 
@@ -944,7 +930,12 @@ func (sm *ShortcutManager) CheckSystem(gsPlatform, gsEnable *gio.Settings, id st
 	platformSet := arr2set(gsPlatform.ListKeys())
 	enableSet := arr2set(gsEnable.ListKeys())
 	sysType := strings.ToLower(systemType())
-
+	assistiveToolsShortcut := []string{
+		"ai-assistant",
+		"speech-to-text",
+		"text-to-speech",
+		"translation",
+	}
 	// 判断是否是支持的平台
 	if platformSet[id] {
 		plats := gsPlatform.GetStrv(id)
@@ -954,6 +945,9 @@ func (sm *ShortcutManager) CheckSystem(gsPlatform, gsEnable *gio.Settings, id st
 			return false
 		}
 	}
+	if sysType == "community" && strv.Strv(assistiveToolsShortcut).Contains(id) {
+		return false
+	}
 
 	// 判断是否配置开启
 	if enableSet[id] && !gsEnable.GetBoolean(id) {
