@@ -4,17 +4,17 @@
 		<message>
 			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
 			<source>Authentication is required to add fingerprint password</source>
-			<translation>Uwierzytelnienie jest wymagane do dodania hasła linii papilarnych</translation>
+			<translation>Wymagane jest uwierzytelnienie do dodania hasła odcisku palca</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
 			<source>Add fingerprint password</source>
-			<translation>Dodaj hasło linii papilarnych</translation>
+			<translation>Dodaj hasło odcisku palca</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
 			<source>Authentication is required to clear fingerprint passwords</source>
-			<translation>Uwierzytelnienie jest wymagane do wyczyszczenia haseł odcisków palców</translation>
+			<translation>Wymagane jest uwierzytelnienie do wyczyszczenia haseł odcisków palców</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
@@ -24,12 +24,12 @@
 		<message>
 			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
 			<source>Authentication is required to rename fingerprint password</source>
-			<translation>Uwierzytelnienie jest wymagane do zmiany nazwy hasła linii papilarnych</translation>
+			<translation>Wymagane jest uwierzytelnienie do zmiany nazwy hasła odcisku palca</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
 			<source>Rename fingerprint password</source>
-			<translation>Zmień nazwę hasła linii papilarnych</translation>
+			<translation>Zmień nazwę hasła odcisku palca</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
