@@ -14,7 +14,7 @@
 		<message>
 			<location filename="com.deepin.daemon.grub2.prepare-gfxmode-detect!message" line="0"/>
 			<source>Authentication is required to prepare grub2 display resolution detection</source>
-			<translation>Uwierzytelnianie jest wymagane do przygotowania wykrywania rozdzielczości grub2</translation>
+			<translation>Uwierzytelnienie jest wymagane do przygotowania wykrywania rozdzielczości grub2</translation>
 		</message>
 		<message>
 			<location filename="com.deepin.daemon.grub2.prepare-gfxmode-detect!description" line="0"/>
