@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package power
 
@@ -25,7 +10,6 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
-	"strings"
 	"sync"
 	"time"
 
@@ -40,7 +24,11 @@ import (
 
 var noUEvent bool
 
-const configManagerId = "org.desktopspec.ConfigManager"
+const (
+	configManagerId = "org.desktopspec.ConfigManager"
+	_configHwSystem = "/usr/share/uos-hw-config"
+)
+
 
 func init() {
 	if arch.Get() == arch.Sunway {
@@ -142,82 +130,14 @@ func newManager(service *dbusutil.Service) (*Manager, error) {
 		BatteryPercentage: 100,
 		cpus:              NewCpuHandlers(),
 	}
+
+	m.refreshSystemPowerPerformance()
+
 	err := m.init()
 	if err != nil {
 		m.destroy()
 		return nil, err
 	}
-	systemBus, err := dbus.SystemBus()
-	if err != nil {
-		return nil, err
-	}
-	m.systemSigLoop = dbusutil.NewSignalLoop(systemBus, 10)
-	m.systemSigLoop.Start()
-	m.initDsgConfig(systemBus)
-
-	path := m.cpus.getCpuGovernorPath()
-	if "" == path {
-		m.IsHighPerformanceSupported = false
-		m.IsBalanceSupported = false
-		m.IsPowerSaveSupported = false
-		return m, nil
-	}
-
-	dsgCpuGovernor := interfaceToString(m.getDsgData("BalanceCpuGovernor"))
-
-	// 装机第一次才会进去，或者手动修改了dconfig的值
-	if interfaceToBool(m.getDsgData("isFirstGetCpuGovernor")) {
-		m.setDsgData("isFirstGetCpuGovernor", false)
-
-		if len(*m.cpus) <= 0 {
-			return m, nil
-		}
-		value, err := m.cpus.getAvailableGovernors()
-		if err != nil {
-			logger.Warning(err)
-			return m, err
-		}
-		value = strings.TrimSpace(string(value))
-		lines := strings.Split(value, " ")
-		// 全部模式都支持的时候,不需要进行写入文件验证
-		if len(lines) != 6 {
-			lines = m.cpus.tryWriteGovernor(lines)
-		}
-		logger.Info(" First. available cpuGovernors : ", lines)
-		m.setDsgData("supportCpuGovernors", setSupportGovernors(lines))
-
-		err, targetGovernor := trySetBalanceCpuGovernor(dsgCpuGovernor)
-		if err != nil {
-			logger.Warning(err)
-		} else {
-			if dsgCpuGovernor != targetGovernor && targetGovernor != "" {
-				m.setDsgData("BalanceCpuGovernor", targetGovernor)
-				logger.Info(" DConfig BalanceCpuGovernor not support. Set Governor : ", targetGovernor)
-			}
-		}
-	} else {
-		supportCpuGovernors := m.getDsgData("supportCpuGovernors")
-		cpuGovernors := interfaceToArrayString(supportCpuGovernors)
-		logger.Info(" dsg translate to Arr cpuGovernors : ", cpuGovernors)
-
-		supportGovernors := make([]string, len(cpuGovernors))
-		for i, v := range cpuGovernors {
-			supportGovernors[i] = v.(string)
-		}
-		setSupportGovernors(supportGovernors)
-	}
-
-	m.IsBalanceSupported = getIsBalanceSupported()
-	m.IsHighPerformanceSupported = getIsHighPerformanceSupported()
-	m.IsPowerSaveSupported = getIsPowerSaveSupported()
-
-	if strv.Strv(getSupportGovernors()).Contains(dsgCpuGovernor) {
-		m.balanceScalingGovernor = dsgCpuGovernor
-	} else {
-		_, m.balanceScalingGovernor = trySetBalanceCpuGovernor(dsgCpuGovernor)
-	}
-
-	logger.Info(" init end. getSupportGovernors ： ", getSupportGovernors(), " , m.balanceScalingGovernor : ", m.balanceScalingGovernor)
 
 	return m, nil
 }
@@ -327,6 +247,112 @@ func (m *Manager) init() error {
 	return nil
 }
 
+func (m *Manager) refreshSystemPowerPerformance() { // 获取系统支持的性能模式
+	systemBus, err := dbus.SystemBus()
+	if err != nil {
+		return
+	}
+	m.systemSigLoop = dbusutil.NewSignalLoop(systemBus, 10)
+	m.initDsgConfig(systemBus)
+	m.systemSigLoop.Start()
+
+	path := m.cpus.getCpuGovernorPath()
+	if "" == path {
+		m.IsHighPerformanceSupported = false
+		m.IsBalanceSupported = false
+		m.IsPowerSaveSupported = false
+		return
+	}
+
+	dsgCpuGovernor := interfaceToString(m.getDsgData("BalanceCpuGovernor"))
+	availableArrGovernors := m.cpus.getAvailableArrGovernors()
+
+	setUseNormalBalance(useNormalBalance())
+	//  如果当前是 平衡模式, 且不走正常平衡模式，且CpuGovernor不是performance, 则需要将m.CpuGovernor设置为performance
+	if m.Mode == "balance" && !getUseNormalBalance() && m.CpuGovernor != "performance" {
+		err := m.doSetCpuGovernor("performance")
+		if err != nil {
+			logger.Warning(err)
+		}
+	}
+
+	// 重启会进去，手动修改了dconfig的值才会进入else
+	if interfaceToBool(m.getDsgData("isFirstGetCpuGovernor")) {
+		if len(*m.cpus) <= 0 {
+			return
+		}
+
+		// 全部模式都支持的时候,不需要进行写入文件验证
+		if len(availableArrGovernors) != 6 {
+			availableArrGovernors = m.cpus.tryWriteGovernor(availableArrGovernors)
+		}
+		logger.Info(" First. available cpuGovernors : ", availableArrGovernors)
+		m.setDsgData("supportCpuGovernors", setSupportGovernors(availableArrGovernors))
+		setLocalAvailableGovernors(availableArrGovernors)
+
+		err, targetGovernor := trySetBalanceCpuGovernor(dsgCpuGovernor)
+		if err != nil {
+			logger.Warning(err)
+		} else {
+			if dsgCpuGovernor != targetGovernor && targetGovernor != "" {
+				m.setDsgData("BalanceCpuGovernor", targetGovernor)
+				logger.Info(" DConfig BalanceCpuGovernor not support. Set Governor : ", targetGovernor)
+			}
+		}
+	} else {
+		supportCpuGovernors := m.getDsgData("supportCpuGovernors")
+		cpuGovernors := interfaceToArrayString(supportCpuGovernors)
+		logger.Info(" dsg translate to Arr cpuGovernors : ", cpuGovernors)
+
+		supportGovernors := make([]string, len(cpuGovernors))
+		for i, v := range cpuGovernors {
+			supportGovernors[i] = v.(string)
+		}
+		setSupportGovernors(supportGovernors)
+		setLocalAvailableGovernors(availableArrGovernors)
+	}
+
+	m.IsBalanceSupported = getIsBalanceSupported()
+	m.IsHighPerformanceSupported = getIsHighPerformanceSupported()
+	m.IsPowerSaveSupported = getIsPowerSaveSupported()
+
+	if strv.Strv(getSupportGovernors()).Contains(dsgCpuGovernor) {
+		m.balanceScalingGovernor = dsgCpuGovernor
+	} else {
+		_, m.balanceScalingGovernor = trySetBalanceCpuGovernor(dsgCpuGovernor)
+	}
+
+	if !m.IsBalanceSupported {
+		logger.Info(" init end. getSupportGovernors ： ", getSupportGovernors(), " , m.balanceScalingGovernor : ", m.balanceScalingGovernor)
+		return
+	}
+
+	// 当支持平衡模式时, 错误将dsg配置设置成""或不支持的值, 则使用默认的平衡模式
+	if m.balanceScalingGovernor == "" || isSystemSupportMode(interfaceToString(m.getDsgData("BalanceCpuGovernor"))) {
+		availableArrGovsLen := len(availableArrGovernors)
+		if availableArrGovsLen <= 0 {
+			m.IsBalanceSupported = false
+			return
+		} else {
+			for i, v := range availableArrGovernors{
+				if strv.Strv(getScalingBalanceAvailableGovernors()).Contains(v) && !isSystemSupportMode(m.balanceScalingGovernor) {
+					m.balanceScalingGovernor = v
+					m.setDsgData("BalanceCpuGovernor", m.balanceScalingGovernor)
+					break
+				}
+
+				if i == availableArrGovsLen {
+					m.IsBalanceSupported = false
+					break
+				}
+			}
+
+		}
+	}
+
+	logger.Info(" init end. getSupportGovernors ： ", getSupportGovernors(), " , m.balanceScalingGovernor : ", m.balanceScalingGovernor)
+}
+
 func (m *Manager) handleUEvent(client *gudev.Client, action string, device *gudev.Device) {
 	logger.Debug("on uevent action:", action)
 	defer device.Unref()
@@ -636,6 +662,12 @@ func (m *Manager) doSetCpuBoost(enabled bool) error {
 }
 
 func (m *Manager) doSetCpuGovernor(governor string) error {
+	// 节能模式，高性能模式不受影响
+	if governor != "powersave" && governor != "performance" && !getUseNormalBalance() {
+		governor = "performance"
+		logger.Infof("[doSetCpuGovernor] change governor : %s to performance.", governor)
+	}
+
 	err := m.cpus.SetGovernor(governor)
 	if err == nil {
 		m.setPropCpuGovernor(governor)
